# pybind

Python bindings for creating `distribute` configs

## Developing

In your virtual environment:

```
maturin develop
```

## Virtual Environments

create a virtual environment:

```
python3 -m venv .venv
```

```
source .venv/bin/activate
```

For fish shells:

```
source .venv/bin/activate.fish
```

## Example

See the [user documentation](https://fluid-dynamics-group.github.io/distribute-docs/python_api.html) page in on the python api for a worked example
